==> plplot-5.11.0.tar.gz: plplot-5.11.0/doc/doxygen/html/annotated.js <==
var annotated =
[
    [ "makedocstrings", "namespacemakedocstrings.html", null ],
    [ "plcallback", "namespaceplcallback.html", null ],
    [ "Plframe", "namespacePlframe.html", "namespacePlframe" ],
    [ "plplot", "namespaceplplot.html", "namespaceplplot" ],
    [ "plplotc", "namespaceplplotc.html", "namespaceplplotc" ],
    [ "plplotcanvas", "namespaceplplotcanvas.html", "namespaceplplotcanvas" ],
    [ "Swig", "namespaceSwig.html", null ],
    [ "TclSup", "namespaceTclSup.html", null ],
    [ "__dlhandle", "struct____dlhandle.html", "struct____dlhandle" ],
    [ "_plm_format", "struct__plm__format.html", "struct__plm__format" ],
    [ "_plm_version", "struct__plm__version.html", "struct__plm__version" ],
    [ "_PlplotCanvas", "struct__PlplotCanvas.html", "struct__PlplotCanvas" ],
    [ "_PlplotCanvasClass", "struct__PlplotCanvasClass.html", "struct__PlplotCanvasClass" ],
    [ "_PlplotCanvasHacktext", "struct__PlplotCanvasHacktext.html", "struct__PlplotCanvasHacktext" ],
    [ "_PlplotCanvasHacktextClass", "struct__PlplotCanvasHacktextClass.html", "struct__PlplotCanvasHacktextClass" ],
    [ "_PlplotCanvasHacktextPriv", "struct__PlplotCanvasHacktextPriv.html", "struct__PlplotCanvasHacktextPriv" ],
    [ "_state", "struct__state.html", "struct__state" ],
    [ "arc_struct", "structarc__struct.html", "structarc__struct" ],
    [ "cdImageStruct", "structcdImageStruct.html", "structcdImageStruct" ],
    [ "cdPointStruct", "structcdPointStruct.html", "structcdPointStruct" ],
    [ "circle", "structcircle.html", "structcircle" ],
    [ "CmdInfo", "structCmdInfo.html", "structCmdInfo" ],
    [ "Command", "structCommand.html", "structCommand" ],
    [ "cont_level", "structcont__level.html", "structcont__level" ],
    [ "cont_line", "structcont__line.html", "structcont__line" ],
    [ "Contourable_Data", "classContourable__Data.html", "classContourable__Data" ],
    [ "Coord_2d", "classCoord__2d.html", "classCoord__2d" ],
    [ "Coord_Xformer", "classCoord__Xformer.html", "classCoord__Xformer" ],
    [ "csa", "structcsa.html", "structcsa" ],
    [ "cxx_pltr2", "classcxx__pltr2.html", "classcxx__pltr2" ],
    [ "delaunay", "structdelaunay.html", "structdelaunay" ],
    [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
    [ "DIR", "structDIR.html", "structDIR" ],
    [ "dirent", "structdirent.html", "structdirent" ],
    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html", "classDrawingObjectsChanger" ],
    [ "DrvOpt", "structDrvOpt.html", "structDrvOpt" ],
    [ "DrvOptCmd", "structDrvOptCmd.html", "structDrvOptCmd" ],
    [ "EscText", "structEscText.html", "structEscText" ],
    [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", "structFCI__to__FontName__Table" ],
    [ "GcwPLdev", "structGcwPLdev.html", "structGcwPLdev" ],
    [ "hashtable", "structhashtable.html", "structhashtable" ],
    [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", "structHershey__to__Unicode__table" ],
    [ "ht_bucket", "structht__bucket.html", "structht__bucket" ],
    [ "IMG_DT", "structIMG__DT.html", "structIMG__DT" ],
    [ "istack", "structistack.html", "structistack" ],
    [ "line", "structline.html", "structline" ],
    [ "lpi", "structlpi.html", "structlpi" ],
    [ "lweights", "structlweights.html", "structlweights" ],
    [ "MasterHandler", "classMasterHandler.html", "classMasterHandler" ],
    [ "MemoryMapHeader", "structMemoryMapHeader.html", "structMemoryMapHeader" ],
    [ "MJDtimeStruct", "structMJDtimeStruct.html", "structMJDtimeStruct" ],
    [ "nn_weights", "structnn__weights.html", "structnn__weights" ],
    [ "nnai", "structnnai.html", "structnnai" ],
    [ "nnhpi", "structnnhpi.html", "structnnhpi" ],
    [ "nnpi", "structnnpi.html", "structnnpi" ],
    [ "octave_swig_packed", "classoctave__swig__packed.html", "classoctave__swig__packed" ],
    [ "octave_swig_ref", "classoctave__swig__ref.html", "classoctave__swig__ref" ],
    [ "octave_swig_type", "classoctave__swig__type.html", "classoctave__swig__type" ],
    [ "octave_value_ref", "structoctave__value__ref.html", "structoctave__value__ref" ],
    [ "OriginChanger", "classOriginChanger.html", "classOriginChanger" ],
    [ "pattern", "structpattern.html", "structpattern" ],
    [ "PDFstrm", "structPDFstrm.html", "structPDFstrm" ],
    [ "plbuffer", "structplbuffer.html", "structplbuffer" ],
    [ "PLBufferingCB", "structPLBufferingCB.html", "structPLBufferingCB" ],
    [ "PLCairo", "structPLCairo.html", "structPLCairo" ],
    [ "PLcGrid", "structPLcGrid.html", "structPLcGrid" ],
    [ "PLcGrid2", "structPLcGrid2.html", "structPLcGrid2" ],
    [ "PLColor", "structPLColor.html", "structPLColor" ],
    [ "PLControlPt", "structPLControlPt.html", "structPLControlPt" ],
    [ "PLDev", "structPLDev.html", "structPLDev" ],
    [ "PLDispatchTable", "structPLDispatchTable.html", "structPLDispatchTable" ],
    [ "PLDisplay", "structPLDisplay.html", "structPLDisplay" ],
    [ "plf2ops_t", "structplf2ops__t.html", "structplf2ops__t" ],
    [ "PLfGrid", "structPLfGrid.html", "structPLfGrid" ],
    [ "PLfGrid2", "structPLfGrid2.html", "structPLfGrid2" ],
    [ "PlFrame", "structPlFrame.html", "structPlFrame" ],
    [ "PLGraphicsIn", "structPLGraphicsIn.html", "structPLGraphicsIn" ],
    [ "PLiodev", "structPLiodev.html", "structPLiodev" ],
    [ "PLLabelDefaults", "structPLLabelDefaults.html", "structPLLabelDefaults" ],
    [ "PLmDev", "structPLmDev.html", "structPLmDev" ],
    [ "PLMemoryMap", "classPLMemoryMap.html", "classPLMemoryMap" ],
    [ "PLmIndex", "structPLmIndex.html", "structPLmIndex" ],
    [ "PLNamedMutex", "classPLNamedMutex.html", "classPLNamedMutex" ],
    [ "PLNamedMutexLocker", "classPLNamedMutexLocker.html", "classPLNamedMutexLocker" ],
    [ "PLOptionInfo", "structPLOptionInfo.html", "structPLOptionInfo" ],
    [ "PLOptionTable", "structPLOptionTable.html", "structPLOptionTable" ],
    [ "plplot", "classplplot.html", "classplplot" ],
    [ "plplot_graphics", "classplplot__graphics.html", [
      [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ]
    ] ],
    [ "plplot_str", "classplplot__str.html", "classplplot__str" ],
    [ "plplot_strutils", "classplplot__strutils.html", "classplplot__strutils" ],
    [ "plplot_types", "classplplot__types.html", "classplplot__types" ],
    [ "plplotp", "classplplotp.html", [
      [ "plcont", "interfaceplplotp_1_1plcont.html", "interfaceplplotp_1_1plcont" ],
      [ "plimagefr", "interfaceplplotp_1_1plimagefr.html", "interfaceplplotp_1_1plimagefr" ],
      [ "plshade", "interfaceplplotp_1_1plshade.html", "interfaceplplotp_1_1plshade" ],
      [ "plshades", "interfaceplplotp_1_1plshades.html", "interfaceplplotp_1_1plshades" ],
      [ "plvect", "interfaceplplotp_1_1plvect.html", "interfaceplplotp_1_1plvect" ]
    ] ],
    [ "PlPlotter", "structPlPlotter.html", "structPlPlotter" ],
    [ "PLRDev", "structPLRDev.html", "structPLRDev" ],
    [ "PLS", "classPLS.html", "classPLS" ],
    [ "PLStream", "structPLStream.html", "structPLStream" ],
    [ "plstream", "classplstream.html", "classplstream" ],
    [ "PLStrip", "structPLStrip.html", "structPLStrip" ],
    [ "PLWindow", "structPLWindow.html", "structPLWindow" ],
    [ "point", "structpoint.html", "structpoint" ],
    [ "PSDev", "structPSDev.html", "structPSDev" ],
    [ "pt", "structpt.html", "structpt" ],
    [ "PyHeapTypeObject", "structPyHeapTypeObject.html", "structPyHeapTypeObject" ],
    [ "QGlobalSpace", "classQGlobalSpace.html", null ],
    [ "QSASConfigStruct", "structQSASConfigStruct.html", "structQSASConfigStruct" ],
    [ "QtPLDriver", "classQtPLDriver.html", "classQtPLDriver" ],
    [ "Rand", "classRand.html", "classRand" ],
    [ "Scaler", "classScaler.html", "classScaler" ],
    [ "square", "structsquare.html", "structsquare" ],
    [ "SVG", "structSVG.html", "structSVG" ],
    [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
    [ "swig_const_info", "structswig__const__info.html", "structswig__const__info" ],
    [ "swig_globalvar", "structswig__globalvar.html", "structswig__globalvar" ],
    [ "SWIG_JavaExceptions_t", "structSWIG__JavaExceptions__t.html", "structSWIG__JavaExceptions__t" ],
    [ "swig_lua_attribute", "structswig__lua__attribute.html", "structswig__lua__attribute" ],
    [ "swig_lua_class", "structswig__lua__class.html", "structswig__lua__class" ],
    [ "swig_lua_const_info", "structswig__lua__const__info.html", "structswig__lua__const__info" ],
    [ "swig_lua_method", "structswig__lua__method.html", "structswig__lua__method" ],
    [ "swig_lua_rawdata", "structswig__lua__rawdata.html", "structswig__lua__rawdata" ],
    [ "swig_lua_userdata", "structswig__lua__userdata.html", "structswig__lua__userdata" ],
    [ "swig_lua_var_info", "structswig__lua__var__info.html", "structswig__lua__var__info" ],
    [ "swig_module_info", "structswig__module__info.html", "structswig__module__info" ],
    [ "swig_octave_class", "structswig__octave__class.html", "structswig__octave__class" ],
    [ "swig_octave_member", "structswig__octave__member.html", "structswig__octave__member" ],
    [ "swig_type_info", "structswig__type__info.html", "structswig__type__info" ],
    [ "swig_varlinkobject", "structswig__varlinkobject.html", "structswig__varlinkobject" ],
    [ "SwigPyClientData", "structSwigPyClientData.html", "structSwigPyClientData" ],
    [ "SwigPyObject", "structSwigPyObject.html", "structSwigPyObject" ],
    [ "SwigPyPacked", "structSwigPyPacked.html", "structSwigPyPacked" ],
    [ "TAI_UTC", "structTAI__UTC.html", "structTAI__UTC" ],
    [ "tclMatrix", "structtclMatrix.html", "structtclMatrix" ],
    [ "tclMatrixXtnsnDescr", "structtclMatrixXtnsnDescr.html", "structtclMatrixXtnsnDescr" ],
    [ "TextObjectsChanger", "classTextObjectsChanger.html", "classTextObjectsChanger" ],
    [ "TkDev", "structTkDev.html", "structTkDev" ],
    [ "TkwDev", "structTkwDev.html", "structTkwDev" ],
    [ "TkwDisplay", "structTkwDisplay.html", "structTkwDisplay" ],
    [ "triangle", "structtriangle.html", "structtriangle" ],
    [ "triangle_neighbours", "structtriangle__neighbours.html", "structtriangle__neighbours" ],
    [ "Unicode_to_Type1_table", "structUnicode__to__Type1__table.html", "structUnicode__to__Type1__table" ],
    [ "wxPLDevice", "classwxPLDevice.html", "classwxPLDevice" ],
    [ "wxPLplotstream", "classwxPLplotstream.html", "classwxPLplotstream" ],
    [ "wxPLplotwindow", "classwxPLplotwindow.html", "classwxPLplotwindow" ],
    [ "XwDev", "structXwDev.html", "structXwDev" ],
    [ "XwDisplay", "structXwDisplay.html", "structXwDisplay" ]
];

==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/annotated.js <==
var annotated =
[
    [ "plplot", "namespaceplplot.html", "namespaceplplot" ],
    [ "plplotc", "namespaceplplotc.html", "namespaceplplotc" ],
    [ "plplotc_fixed", "namespaceplplotc__fixed.html", "namespaceplplotc__fixed" ],
    [ "__dlhandle", "struct____dlhandle.html", "struct____dlhandle" ],
    [ "_plm_format", "struct__plm__format.html", "struct__plm__format" ],
    [ "_plm_version", "struct__plm__version.html", "struct__plm__version" ],
    [ "_state", "struct__state.html", "struct__state" ],
    [ "arc_struct", "structarc__struct.html", "structarc__struct" ],
    [ "cdImageStruct", "structcdImageStruct.html", "structcdImageStruct" ],
    [ "cdPointStruct", "structcdPointStruct.html", "structcdPointStruct" ],
    [ "circle", "structcircle.html", "structcircle" ],
    [ "Clipper", "classClipper.html", "classClipper" ],
    [ "CmdInfo", "structCmdInfo.html", "structCmdInfo" ],
    [ "Command", "structCommand.html", "structCommand" ],
    [ "cont_level", "structcont__level.html", "structcont__level" ],
    [ "cont_line", "structcont__line.html", "structcont__line" ],
    [ "Contourable_Data", "classContourable__Data.html", "classContourable__Data" ],
    [ "Coord_2d", "classCoord__2d.html", "classCoord__2d" ],
    [ "Coord_Xformer", "classCoord__Xformer.html", "classCoord__Xformer" ],
    [ "csa", "structcsa.html", "structcsa" ],
    [ "cxx_pltr2", "classcxx__pltr2.html", "classcxx__pltr2" ],
    [ "delaunay", "structdelaunay.html", "structdelaunay" ],
    [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
    [ "DIR", "structDIR.html", "structDIR" ],
    [ "dirent", "structdirent.html", "structdirent" ],
    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html", "classDrawingObjectsChanger" ],
    [ "DrvOpt", "structDrvOpt.html", "structDrvOpt" ],
    [ "DrvOptCmd", "structDrvOptCmd.html", "structDrvOptCmd" ],
    [ "EscText", "structEscText.html", "structEscText" ],
    [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", "structFCI__to__FontName__Table" ],
    [ "Font", "classFont.html", "classFont" ],
    [ "FontGrabber", "classFontGrabber.html", "classFontGrabber" ],
    [ "hashtable", "structhashtable.html", "structhashtable" ],
    [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", "structHershey__to__Unicode__table" ],
    [ "ht_bucket", "structht__bucket.html", "structht__bucket" ],
    [ "IMG_DT", "structIMG__DT.html", "structIMG__DT" ],
    [ "istack", "structistack.html", "structistack" ],
    [ "line", "structline.html", "structline" ],
    [ "lpi", "structlpi.html", "structlpi" ],
    [ "lweights", "structlweights.html", "structlweights" ],
    [ "MasterHandler", "classMasterHandler.html", "classMasterHandler" ],
    [ "MemoryMapHeader", "structMemoryMapHeader.html", "structMemoryMapHeader" ],
    [ "MJDtimeStruct", "structMJDtimeStruct.html", "structMJDtimeStruct" ],
    [ "nn_weights", "structnn__weights.html", "structnn__weights" ],
    [ "nnai", "structnnai.html", "structnnai" ],
    [ "nnhpi", "structnnhpi.html", "structnnhpi" ],
    [ "nnpi", "structnnpi.html", "structnnpi" ],
    [ "octave_swig_packed", "classoctave__swig__packed.html", "classoctave__swig__packed" ],
    [ "octave_swig_ref", "classoctave__swig__ref.html", "classoctave__swig__ref" ],
    [ "octave_swig_type", "classoctave__swig__type.html", "classoctave__swig__type" ],
    [ "octave_value_ref", "structoctave__value__ref.html", "structoctave__value__ref" ],
    [ "OriginChanger", "classOriginChanger.html", "classOriginChanger" ],
    [ "pattern", "structpattern.html", "structpattern" ],
    [ "PDFstrm", "structPDFstrm.html", "structPDFstrm" ],
    [ "plbuffer", "structplbuffer.html", "structplbuffer" ],
    [ "PLBufferingCB", "structPLBufferingCB.html", "structPLBufferingCB" ],
    [ "PLCairo", "structPLCairo.html", "structPLCairo" ],
    [ "PLcGrid", "structPLcGrid.html", "structPLcGrid" ],
    [ "PLcGrid2", "structPLcGrid2.html", "structPLcGrid2" ],
    [ "PLColor", "structPLColor.html", "structPLColor" ],
    [ "PLControlPt", "structPLControlPt.html", "structPLControlPt" ],
    [ "PLDev", "structPLDev.html", "structPLDev" ],
    [ "PlDevice", "classPlDevice.html", "classPlDevice" ],
    [ "PLDispatchTable", "structPLDispatchTable.html", "structPLDispatchTable" ],
    [ "PLDisplay", "structPLDisplay.html", "structPLDisplay" ],
    [ "plf2ops_t", "structplf2ops__t.html", "structplf2ops__t" ],
    [ "PLfGrid", "structPLfGrid.html", "structPLfGrid" ],
    [ "PLfGrid2", "structPLfGrid2.html", "structPLfGrid2" ],
    [ "PlFrame", "structPlFrame.html", "structPlFrame" ],
    [ "PLGraphicsIn", "structPLGraphicsIn.html", "structPLGraphicsIn" ],
    [ "PLiodev", "structPLiodev.html", "structPLiodev" ],
    [ "PLLabelDefaults", "structPLLabelDefaults.html", "structPLLabelDefaults" ],
    [ "PLmDev", "structPLmDev.html", "structPLmDev" ],
    [ "PLMemoryMap", "classPLMemoryMap.html", "classPLMemoryMap" ],
    [ "PLmIndex", "structPLmIndex.html", "structPLmIndex" ],
    [ "PLNamedMutex", "classPLNamedMutex.html", "classPLNamedMutex" ],
    [ "PLNamedMutexLocker", "classPLNamedMutexLocker.html", "classPLNamedMutexLocker" ],
    [ "PLOptionInfo", "structPLOptionInfo.html", "structPLOptionInfo" ],
    [ "PLOptionTable", "structPLOptionTable.html", "structPLOptionTable" ],
    [ "plplot", "classplplot.html", "classplplot" ],
    [ "plplot_double", "classplplot__double.html", "classplplot__double" ],
    [ "plplot_graphics", "classplplot__graphics.html", "classplplot__graphics" ],
    [ "plplot_private_exposed", "classplplot__private__exposed.html", "classplplot__private__exposed" ],
    [ "plplot_private_utilities", "classplplot__private__utilities.html", "classplplot__private__utilities" ],
    [ "plplot_single", "classplplot__single.html", "classplplot__single" ],
    [ "plplot_types", "classplplot__types.html", "classplplot__types" ],
    [ "PlPlotter", "structPlPlotter.html", "structPlPlotter" ],
    [ "PLRDev", "structPLRDev.html", "structPLRDev" ],
    [ "PLS", "classPLS.html", "classPLS" ],
    [ "plstream", "classplstream.html", "classplstream" ],
    [ "PLStream", "structPLStream.html", "structPLStream" ],
    [ "PLStrip", "structPLStrip.html", "structPLStrip" ],
    [ "PLWindow", "structPLWindow.html", "structPLWindow" ],
    [ "point", "structpoint.html", "structpoint" ],
    [ "PSDev", "structPSDev.html", "structPSDev" ],
    [ "pt", "structpt.html", "structpt" ],
    [ "PyHeapTypeObject", "structPyHeapTypeObject.html", "structPyHeapTypeObject" ],
    [ "QGlobalSpace", "classQGlobalSpace.html", null ],
    [ "QSASConfigStruct", "structQSASConfigStruct.html", "structQSASConfigStruct" ],
    [ "QtPLDriver", "classQtPLDriver.html", "classQtPLDriver" ],
    [ "Rand", "classRand.html", "classRand" ],
    [ "Scaler", "classScaler.html", "classScaler" ],
    [ "square", "structsquare.html", "structsquare" ],
    [ "SVG", "structSVG.html", "structSVG" ],
    [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
    [ "swig_const_info", "structswig__const__info.html", "structswig__const__info" ],
    [ "swig_globalvar", "structswig__globalvar.html", "structswig__globalvar" ],
    [ "swig_lua_attribute", "structswig__lua__attribute.html", "structswig__lua__attribute" ],
    [ "swig_lua_class", "structswig__lua__class.html", "structswig__lua__class" ],
    [ "swig_lua_const_info", "structswig__lua__const__info.html", "structswig__lua__const__info" ],
    [ "swig_lua_method", "structswig__lua__method.html", "structswig__lua__method" ],
    [ "swig_lua_namespace", "structswig__lua__namespace.html", "structswig__lua__namespace" ],
    [ "swig_lua_rawdata", "structswig__lua__rawdata.html", "structswig__lua__rawdata" ],
    [ "swig_lua_userdata", "structswig__lua__userdata.html", "structswig__lua__userdata" ],
    [ "swig_lua_var_info", "structswig__lua__var__info.html", "structswig__lua__var__info" ],
    [ "swig_module_info", "structswig__module__info.html", "structswig__module__info" ],
    [ "swig_octave_class", "structswig__octave__class.html", "structswig__octave__class" ],
    [ "swig_octave_member", "structswig__octave__member.html", "structswig__octave__member" ],
    [ "swig_type_info", "structswig__type__info.html", "structswig__type__info" ],
    [ "swig_varlinkobject", "structswig__varlinkobject.html", "structswig__varlinkobject" ],
    [ "SwigPyClientData", "structSwigPyClientData.html", "structSwigPyClientData" ],
    [ "SwigPyObject", "structSwigPyObject.html", "structSwigPyObject" ],
    [ "SwigPyPacked", "structSwigPyPacked.html", "structSwigPyPacked" ],
    [ "TAI_UTC", "structTAI__UTC.html", "structTAI__UTC" ],
    [ "tclMatrix", "structtclMatrix.html", "structtclMatrix" ],
    [ "tclMatrixXtnsnDescr", "structtclMatrixXtnsnDescr.html", "structtclMatrixXtnsnDescr" ],
    [ "TextObjectsChanger", "classTextObjectsChanger.html", "classTextObjectsChanger" ],
    [ "TextObjectsSaver", "classTextObjectsSaver.html", "classTextObjectsSaver" ],
    [ "TextSizeInfo", "structTextSizeInfo.html", "structTextSizeInfo" ],
    [ "TkDev", "structTkDev.html", "structTkDev" ],
    [ "TkwDev", "structTkwDev.html", "structTkwDev" ],
    [ "TkwDisplay", "structTkwDisplay.html", "structTkwDisplay" ],
    [ "triangle", "structtriangle.html", "structtriangle" ],
    [ "triangle_neighbours", "structtriangle__neighbours.html", "structtriangle__neighbours" ],
    [ "Unicode_to_Type1_table", "structUnicode__to__Type1__table.html", "structUnicode__to__Type1__table" ],
    [ "wxPLDevice", "classwxPLDevice.html", "classwxPLDevice" ],
    [ "wxPLplotstream", "classwxPLplotstream.html", "classwxPLplotstream" ],
    [ "wxPLplotwindow", "classwxPLplotwindow.html", "classwxPLplotwindow" ],
    [ "XwDev", "structXwDev.html", "structXwDev" ],
    [ "XwDisplay", "structXwDisplay.html", "structXwDisplay" ]
];
